Index: runtime/observatory/lib/src/models/objects/thread.dart |
diff --git a/runtime/observatory/lib/src/models/objects/thread.dart b/runtime/observatory/lib/src/models/objects/thread.dart |
index 7bff72c9191eb98a34a8a0a5a15c7741dee29909..be461fdf4845fe97653cee7ceab584f38cdf5fde 100644 |
--- a/runtime/observatory/lib/src/models/objects/thread.dart |
+++ b/runtime/observatory/lib/src/models/objects/thread.dart |
@@ -20,10 +20,10 @@ abstract class Thread { |
/// The task type associated with the thread. |
ThreadKind get kind; |
- /// The maximum amount of memory in bytes allocated by a thread at a given |
- /// time throughout the entire life of the thread. |
- int get memoryHighWatermark; |
+ /// The maximum amount of zone memory in bytes allocated by a thread at a |
+ /// given time throughout the entire life of the thread. |
+ int get zoneHighWatermark; |
- /// A list of all the zones held by the thread. |
- Iterable<Zone> get zones; |
+ /// The current Zone capacity available to this thread. |
+ int get zoneCapacity; |
} |